const { Helpers } = require('../controller/helpers');
const { PostModel } = require('../controller/index')

module.exports = {
    fetchPost: async function (req, res) {
        const reuslt = await PostModel.fetch();
        if (reuslt.length > 0) {
            reuslt.map((post) => {
                post.image = encodeURI(`${process.env.UPLOAD_URL}${post.image}`)
                delete post.sidbar_image
                delete post.content
                delete post.mobile_ad
                delete post.custom_script
            })
            return res.status(200).json(Helpers.sendResponse("success", reuslt, `Post Fetch Successfully`))
        }
        return res.status(404).json(Helpers.sendResponse("fail", [], `Not Found`))
    },
    fetchPostDetail: async function (req, res) {
        const { postid } = req.params
        const reuslt = await PostModel.fetch("post_id", postid);
        if (reuslt.length > 0) {
            reuslt.map((post) => {
                post.image = post.image ? encodeURI(`${process.env.UPLOAD_URL}${post.image}`) : ""
                post.content = post.content.split("/admin/ckeditor/kcfinder/upload/images/").join(process.env.UPLOAD_URL)
                post.content = post.content.split("http://ayurvedalifecare.in/admin/ckeditor/plugins/smiley/images/").join(process.env.UPLOAD_URL)
                delete post.sidbar_image
                delete post.mobile_ad
                delete post.custom_script
            })
            return res.status(200).json(Helpers.sendResponse("success", reuslt, `Post Fetch Successfully`))
        }
        return res.status(404).json(Helpers.sendResponse("fail", [], `Not Found`))
    },
    fetchBlogDetail: async function (req, res) {
        const { blogname } = req.params
        const reuslt = await PostModel.fetch("blog_name", blogname, ["title", "category", "content", "form_name", "date", "meta_title", "image", "meta_desc", "submit_redirection as redirection", "redirection_blog_url", "redirection_status"]);
        if (reuslt.length > 0) {
            reuslt.map((post) => {
                post.image = encodeURI(`${process.env.UPLOAD_URL}${post.image}`)
                post.content = post.content.split("/admin/ckeditor/kcfinder/upload/images/").join(process.env.UPLOAD_URL)
                post.content = post.content.split("https://ayurvedalifecare.in/admin/ckeditor/plugins/smiley/images/").join(process.env.UPLOAD_URL)
                delete post.sidbar_image
                delete post.mobile_ad
                delete post.custom_script
            })
            return res.status(200).json(Helpers.sendResponse("success", reuslt, `Post Fetch Successfully`))
        }
        return res.status(404).json(Helpers.sendResponse("fail", [], `Not Found`))
    },
    category: async function (req, res) {
        const reuslt = await PostModel.fetchCat();
        if (reuslt.length > 0) {
            return res.status(200).json(Helpers.sendResponse("success", reuslt, `Category Fetch Successfully`))
        }
        return res.status(404).json(Helpers.sendResponse("fail", [], `Not Found`))
    },
    products: async function (req, res) {
        const reuslt = await PostModel.fetchProduct();
        if (reuslt.length > 0) {
            return res.status(200).json(Helpers.sendResponse("success", reuslt, `Products Fetch Successfully`))
        }
        return res.status(404).json(Helpers.sendResponse("fail", [], `Not Found`))
    },
    languages: async function (req, res) {
        const reuslt = await PostModel.fetchLang();
        if (reuslt.length > 0) {
            return res.status(200).json(Helpers.sendResponse("success", reuslt, `Languages Fetch Successfully`))
        }
        return res.status(404).json(Helpers.sendResponse("fail", [], `Not Found`))
    },
    editPost: async function (req, res) {
        const REQUIRED = ["title", "content", "category", "image", "blog_name", "form_name", "product", "language", "submit_redirection", "meta_title", "meta_desc", "publish"]
        const FIELD_GET = Object.keys(req.body)
        if (FIELD_GET.doesContainsAll(REQUIRED)) {
            const { title, content, category, blog_name, alternate_blog_name, alternate_button_title, product, language, form_name, submit_redirection, meta_title, meta_desc, publish } = req.body
            const { post_id } = req.params
            const set = {
                title,
                content,
                category,
                product,
                language,
                blog_name,
                form_name,
                image: req.body.image || "",
                submit_redirection,
                meta_title,
                meta_desc,
                publish,
            }
            if (alternate_blog_name !== undefined && alternate_blog_name !== null && alternate_blog_name !== '') {
                set['alternate_blog_name'] = alternate_blog_name
                if (alternate_button_title !== undefined && alternate_button_title !== null && alternate_button_title !== '') {
                    set['alternate_button_title'] = alternate_button_title
                } else {
                    return res.status(400).json(Helpers.sendResponse("fail", [], `Alternate button title is required when alternate post is given`))
                }
            } else {
                set['alternate_blog_name'] = null
            }
            const where = {
                post_id
            }
            const result = await PostModel.update([set, where])
            if (result.affectedRows > 0) {
                return res.status(200).json(Helpers.sendResponse("success", [], `Updated Successfully`))
            }
            return res.status(400).json(Helpers.sendResponse("fail", [], `Post Not Available`))
        }
        return res.status(400).json(Helpers.sendResponse("fail", [], `Key Mismatch`))
    },
    deletePost: async function (req, res) {
        const { post_id } = req.params
        if (typeof post_id != "undefined" || post_id != "") {
            const result = await PostModel.delete([post_id])
            if (result.affectedRows > 0) {
                return res.status(200).json(Helpers.sendResponse("success", [], `Deleted Successfully`))
            }
            return res.status(400).json(Helpers.sendResponse("fail", [], `Post id Not Available`))
        }
        return res.status(400).json(Helpers.sendResponse("fail", [], `Post id Not Defined`))
    },
    uploadImage: async function (req, res) {
        let path = `${req.file.destination.split("/").slice(0).join("/")}/${req.file.filename}`
        let file_name = path.split("/").slice(-1)[0]
        return res
            .status(200)
            .json(Helpers.sendResponse("success", [{ file_name: file_name, uri: `${process.env.UPLOAD_URL}${file_name}` }], `File : ${file_name}`))
    },
    newPost: async function (req, res) {
        const REQUIRED = ["title", "content", "image", "category", "blog_name", "form_name", "product", "language", "submit_redirection", "meta_title", "meta_desc", "publish"]
        const FIELD_GET = Object.keys(req.body)
        if (FIELD_GET.doesContainsAll(REQUIRED)) {
            const { title, content, category, blog_name, form_name, product, language, submit_redirection, meta_title, meta_desc, publish } = req.body
            const create = {
                title,
                content: content.escapeString(),
                category,
                blog_name,
                form_name,
                product,
                language,
                image: req.body.image || "",
                submit_redirection,
                meta_title,
                meta_desc,
                publish,
            }
            // if (alternate_blog_name !== undefined && alternate_blog_name !== null && alternate_blog_name !== '') {
            //         create['alternate_blog_name'] = alternate_blog_name
            //         if (alternate_button_title !== undefined && alternate_button_title !== null && alternate_button_title !== '') {
            //             create['alternate_button_title'] = alternate_button_title
            //         } else {
            //             return res.status(400).json(Helpers.sendResponse("fail", [], `Alternate button title is required when alternate post is given`))
            //         }
            //     }
            const result = await PostModel.create("post", create)
            if (result.affectedRows > 0) {
                return res.status(200).json(Helpers.sendResponse("success", [], `Created Successfully`))
            }
            return res.status(400).json(Helpers.sendResponse("fail", [], `Something Went Wrong`))

        }
        return res.status(400).json(Helpers.sendResponse("fail", [], `Key Mismatch`))
    },
    newcat: async function (req, res) {
        const REQUIRED = ["cat_name"]
        const FIELD_GET = Object.keys(req.body)
        if (REQUIRED.isEqualArray(FIELD_GET)) {
            const { cat_name } = req.body
            const result = await PostModel.create("category", { category_name: cat_name })
            if (result.affectedRows > 0) {
                return res.status(200).json(Helpers.sendResponse("success", [], `Created Successfully`))
            }
        }
        return res.status(400).json(Helpers.sendResponse("fail", [], `Key Mismatch`))
    },
    newproduct: async function (req, res) {
        const REQUIRED = ["name"]
        const FIELD_GET = Object.keys(req.body)
        if (REQUIRED.isEqualArray(FIELD_GET)) {
            const { name } = req.body
            const result = await PostModel.create("product", { name: name })
            if (result.affectedRows > 0) {
                return res.status(200).json(Helpers.sendResponse("success", [], `Created Successfully`))
            }
        }
        return res.status(400).json(Helpers.sendResponse("fail", [], `Key Mismatch`))
    },
    Redirection_updater: async function (req, res) {

        const result = await PostModel.Redirection_updaters(req.body.redirection_status, req.body.post_id)
        if (result.affectedRows > 0) {
            return res.status(200).json(Helpers.sendResponse("success", [], `Updated Successfully`))
        } else {
            return res.status(500).json(Helpers.sendResponse("success", [], `Sumthing went wrong`))
        }
    },
    Redirection_edit: async function (req, res) {
        const result = await PostModel.EditRedirection_url(req.body.redirection_url, req.body.post_id)
        if (result.affectedRows > 0) {
            return res.status(200).json(Helpers.sendResponse("success", [], `Updated Successfully`))
        } else {
            return res.status(500).json(Helpers.sendResponse("success", [], `Sumthing went wrong`))
        }
    },
    AddBlogRedirection: async function (req, res) {
        const result = await PostModel.AddRedirection_url(req.body.redirection_url, req.body.post)
        if (result.affectedRows > 0) {
            return res.status(200).json(Helpers.sendResponse("success", [], `Updated Successfully`))
        } else {
            return res.status(500).json(Helpers.sendResponse("success", [], `Sumthing went wrong`))
        }
    },
    getBlogRedirection: async function (req, res) {
        const result = await PostModel.getRedirections()
        if (result) {
            return res.status(200).json(Helpers.sendResponse("success", [result], `Updated Successfully`,))
        } else {
            return res.status(500).json(Helpers.sendResponse("success", [], `Sumthing went wrong`))
        }
    }
}